@@ -7,8 +7,8 @@ import pkg_resources
 
 from . import dbms, dirs, geom, ops, settings, store, text
 
-with open(pkg_resources.resource_filename(__name__, "data/metadata.json"), mode='r') as metadata_file:
-    metadata = json.load(metadata_file)
+with open(pkg_resources.resource_filename(__name__, "data/metadata.json"), mode='r') as f:
+    metadata = json.load(f)
 
 __project__ = metadata['Project']
 __pkgname__ = metadata['Package']
@@ -24,6 +24,8 @@ __copyright__ = f'2019-{datetime.datetime.now().year}, {__author__}'
 __version__ = metadata['Version']
 __license__ = metadata['License']
 
+__first_release_date__ = metadata['First release']
+
 __all__ = [
     'dbms',
     'dirs',
