@@ -703,7 +703,10 @@ def update_dict(dictionary, updates, inplace=False):
 
     for key, val in updates.items():
         if isinstance(val, collections.abc.Mapping) or isinstance(val, dict):
-            updated_dict[key] = update_dict(dictionary.get(key, {}), val)
+            try:
+                updated_dict[key] = update_dict(dictionary.get(key, {}), val)
+            except TypeError:
+                updated_dict.update({key: val})
 
         elif isinstance(val, list):
             updated_dict[key] = (updated_dict.get(key, []) + val)
@@ -1877,11 +1880,11 @@ def _user_agent_strings(browser_names=None, dump_dat=True):
 
     **Examples**::
 
-        from pyhelpers.ops import _user_agent_strings
+        >>> from pyhelpers.ops import _user_agent_strings
 
-        uas = _user_agent_strings()
-        list(uas.keys())
-        # ['Chrome', 'Firefox', 'Safari', 'Edge', 'Internet Explorer', 'Opera']
+        >>> uas = _user_agent_strings()
+        >>> list(uas.keys())
+        ['Chrome', 'Firefox', 'Safari', 'Edge', 'Internet Explorer', 'Opera']
     """
 
     if browser_names is None:
