@@ -1,23 +1,17 @@
-"""
-Manipulation of textual data.
-"""
+"""Manipulation of textual data."""
 
-import collections.abc
-import copy
-import difflib
-import os
-import pathlib
+import collections
 import re
 import string
-import subprocess
 
 import numpy as np
-import pandas as pd
 
-from ._cache import _ENGLISH_WRITTEN_NUMBERS
-from .ops import dict_to_dataframe, find_executable
+from ._cache import _check_dependency, _ENGLISH_WRITTEN_NUMBERS
 
-""" == Basic processing of textual data ====================================================== """
+
+# ==================================================================================================
+# Textual data preprocessing
+# ==================================================================================================
 
 
 def get_acronym(text, only_capitals=False, capitals_in_words=False):
@@ -72,7 +66,7 @@ def remove_punctuation(x, rm_whitespace=True):
 
     :param x: raw string-type data
     :type x: str
-    :param rm_whitespace: whether to remove whitespace, defaults to ``True``
+    :param rm_whitespace: whether to remove whitespace (incl. escape characters), defaults to ``True``
     :type rm_whitespace: bool
     :return: text with punctuation removed
     :rtype: str
@@ -81,15 +75,15 @@ def remove_punctuation(x, rm_whitespace=True):
 
         >>> from pyhelpers.text import remove_punctuation
 
-        >>> raw_text = 'Hello\tworld! This is a test. :-)'
+        >>> raw_text = 'Hello world!\tThis is a test. :-)'
 
         >>> text = remove_punctuation(raw_text)
         >>> text
-        'Hello\tworld  This is a test'
-
-        >>> text = remove_punctuation(raw_text, rm_whitespace=True)
-        >>> text
         'Hello world This is a test'
+
+        >>> text = remove_punctuation(raw_text, rm_whitespace=False)
+        >>> text
+        'Hello world \tThis is a test'
     """
 
     x_ = re.sub(r'[^\w\s]', ' ', x)
@@ -124,15 +118,15 @@ def extract_words1upper(x, join_with=None):
 
         >>> from pyhelpers.text import extract_words1upper
 
-        >>> x1 = 'NetworkWaymarks'
-        >>> res = extract_words1upper(x1, join_with=' ')
-        >>> res
-        'Network Waymarks'
+        >>> x1 = 'Network_Waymarks'
+        >>> x1_ = extract_words1upper(x1)
+        >>> x1_
+        ['Network', 'Waymarks']
 
-        >>> x2 = 'Retaining_Wall'
-        >>> res = extract_words1upper(x2, join_with=' ')
-        >>> res
-        'Retaining Wall'
+        >>> x2 = 'NetworkRailRetainingWall'
+        >>> x2_ = extract_words1upper(x2, join_with=' ')
+        >>> x2_
+        'Network Rail Retaining Wall'
     """
 
     y = remove_punctuation(x)
@@ -198,148 +192,9 @@ def numeral_english_to_arabic(x):
     return result + current
 
 
-""" == Comparison of textual data ============================================================ """
-
-
-def find_matched_str(x, lookup_list):
-    """
-    Find all that are matched with a string from among a sequence of strings.
-
-    :param x: a string-type variable
-    :type x: str
-    :param lookup_list: a sequence of strings for lookup
-    :type lookup_list: typing.List[str] or typing.Tuple[str] or typing.Sequence[str]
-    :return: a generator containing all that are matched with ``x``
-    :rtype: typing.Generator or None
-
-    **Examples**::
-
-        >>> from pyhelpers.text import find_matched_str
-
-        >>> lookup_lst = ['abc', 'aapl', 'app', 'ap', 'ape', 'apex', 'apel']
-        >>> res = find_matched_str('apple', lookup_lst)
-        >>> list(res)
-        []
-
-        >>> lookup_lst += ['apple']
-        >>> lookup_lst
-        ['abc', 'aapl', 'app', 'ap', 'ape', 'apex', 'apel', 'apple']
-
-        >>> res = find_matched_str('apple', lookup_lst)
-        >>> list(res)
-        ['apple']
-
-        >>> res = find_matched_str(r'app(le)?', lookup_lst)
-        >>> list(res)
-        ['app', 'apple']
-    """
-
-    if x is not None:
-        for y in lookup_list:
-            if re.match(x, y, re.IGNORECASE):
-                yield y
-
-
-def find_similar_str(x, lookup_list, n=1, ignore_punctuation=True, method='difflib', **kwargs):
-    """
-    From among a sequence of strings, find ``n`` ones that are similar to ``x``.
-
-    :param x: a string-type variable
-    :type x: str
-    :param lookup_list: a sequence of strings for lookup
-    :type lookup_list: typing.List[str] or typing.Tuple[str] or typing.Sequence[str]
-    :param n: number of similar strings to return, defaults to ``1``;
-        if ``n=None``, the function returns a sorted ``lookup_list`` (in descending order of similarity)
-    :type n: int or None
-    :param method: options include ``'difflib'`` (default) and ``'fuzzywuzzy'``
-
-        - if ``method='difflib'``, the function relies on `difflib.get_close_matches`_
-        - if ``method='fuzzywuzzy'``, the function relies on `fuzzywuzzy.fuzz.token_set_ratio`_
-
-    :type method: str or None
-
-    :param ignore_punctuation: whether to ignore puctuations in the search for similar texts
-    :type ignore_punctuation: bool
-    :param kwargs: [optional] parameters of `difflib.get_close_matches`_ or
-        `fuzzywuzzy.fuzz.token_set_ratio`_, depending on ``processor``
-    :return: a string-type variable that should be similar to (or the same as) ``x``
-    :rtype: str or list or None
-
-    .. _`difflib.get_close_matches`:
-        https://docs.python.org/3/library/difflib.html#difflib.get_close_matches
-    .. _`fuzzywuzzy.fuzz.token_set_ratio`:
-        https://github.com/seatgeek/fuzzywuzzy
-
-    **Examples**::
-
-        >>> from pyhelpers.text import find_similar_str
-
-        >>> lookup_lst = ['Anglia',
-        ...               'East Coast',
-        ...               'East Midlands',
-        ...               'North and East',
-        ...               'London North Western',
-        ...               'Scotland',
-        ...               'South East',
-        ...               'Wales',
-        ...               'Wessex',
-        ...               'Western']
-
-        >>> str_similar = find_similar_str(x='angle', lookup_list=lookup_lst)
-        >>> str_similar
-        'Anglia'
-        >>> str_similar = find_similar_str(x='angle', lookup_list=lookup_lst, method='fuzzywuzzy')
-        >>> str_similar
-        'Anglia'
-
-        >>> str_similar = find_similar_str(x='x', lookup_list=lookup_lst)
-        >>> str_similar  # None
-
-        >>> str_similar = find_similar_str(x='x', lookup_list=lookup_lst, method='fuzzywuzzy')
-        >>> str_similar
-        'Wessex'
-    """
-
-    assert method in ('difflib', 'fuzzywuzzy', None), \
-        "Options for `processor` include \"difflib\" and \"fuzzywuzzy\"."
-
-    m = len(lookup_list) if n is None else copy.copy(n)
-
-    if method in {'difflib', None}:
-        x_ = x.lower()
-        lookup_dict = {y.lower(): y for y in lookup_list}
-
-        if ignore_punctuation:
-            x_ = remove_punctuation(x_)
-            lookup_dict = {remove_punctuation(k): v for k, v in lookup_dict.items()}
-
-        sim_str_ = difflib.get_close_matches(word=x_, possibilities=lookup_dict.keys(), n=m, **kwargs)
-
-        if not sim_str_:
-            sim_str = None
-        else:
-            sim_str = lookup_dict[sim_str_[0]]
-
-    elif method == 'fuzzywuzzy':
-        import fuzzywuzzy.fuzz
-
-        l_distances = [fuzzywuzzy.fuzz.token_set_ratio(s1=x, s2=a, **kwargs) for a in lookup_list]
-
-        if sum(l_distances) == 0:
-            sim_str = None
-        else:
-            if m == 1:
-                sim_str = lookup_list[l_distances.index(max(l_distances))]
-            else:
-                sim_str = [lookup_list[i] for i in np.argsort(l_distances)[::-1]][:m]
-
-    else:
-        sim_str = None
-
-    return sim_str
-
-
-""" == Basic computation of textual data ===================================================== """
+# ==================================================================================================
+# Textual data computation
+# ==================================================================================================
 
 
 def count_words(raw_txt):
@@ -382,10 +237,10 @@ def count_words(raw_txt):
          'world': 1}
     """
 
-    import nltk
+    nltk_ = _check_dependency(name='nltk')
 
     doc_text = str(raw_txt)
-    tokens = nltk.word_tokenize(doc_text)
+    tokens = nltk_.word_tokenize(doc_text)
 
     word_count_dict = dict(collections.Counter(tokens))
 
@@ -396,32 +251,29 @@ def calculate_idf(raw_documents, rm_punc=False):
     """
     Calculate inverse document frequency.
 
-    :param raw_documents: a series of documents
-    :type raw_documents: pandas.Series
-    :param rm_punc: whether to remove punctuation from ``raw_documents``, defaults to ``False``
+    :param raw_documents: a sequence of textual data
+    :type raw_documents: typing.Iterable or typing.Sequence
+    :param rm_punc: whether to remove punctuation from the input textual data, defaults to ``False``
     :type rm_punc: bool
-    :return: term frequency (TF) of ``raw_documents``, and inverse document frequency
-    :rtype: tuple
+    :return: term frequency (TF) of the input textual data, and inverse document frequency
+    :rtype: tuple[list[dict], dict]
 
     **Examples**::
 
         >>> from pyhelpers.text import calculate_idf
-        >>> import pandas
 
-        >>> raw_doc_ = [
+        >>> raw_doc = [
         ...     'This is an apple.',
         ...     'That is a pear.',
         ...     'It is human being.',
         ...     'Hello world!']
-        >>> raw_doc = pandas.Series(raw_doc_)
 
         >>> docs_tf_, corpus_idf_ = calculate_idf(raw_doc, rm_punc=False)
         >>> docs_tf_
-        0    {'This': 1, 'is': 1, 'an': 1, 'apple': 1, '.': 1}
-        1      {'That': 1, 'is': 1, 'a': 1, 'pear': 1, '.': 1}
-        2    {'It': 1, 'is': 1, 'human': 1, 'being': 1, '.'...
-        3                     {'Hello': 1, 'world': 1, '!': 1}
-        dtype: object
+        [{'This': 1, 'is': 1, 'an': 1, 'apple': 1, '.': 1},
+         {'That': 1, 'is': 1, 'a': 1, 'pear': 1, '.': 1},
+         {'It': 1, 'is': 1, 'human': 1, 'being': 1, '.': 1},
+         {'Hello': 1, 'world': 1, '!': 1}]
 
         >>> corpus_idf_
         {'This': 0.6931471805599453,
@@ -441,11 +293,10 @@ def calculate_idf(raw_documents, rm_punc=False):
 
         >>> docs_tf_, corpus_idf_ = calculate_idf(raw_doc, rm_punc=True)
         >>> docs_tf_
-        0     {'This': 1, 'is': 1, 'an': 1, 'apple': 1}
-        1       {'That': 1, 'is': 1, 'a': 1, 'pear': 1}
-        2    {'It': 1, 'is': 1, 'human': 1, 'being': 1}
-        3                      {'Hello': 1, 'world': 1}
-        dtype: object
+        [{'This': 1, 'is': 1, 'an': 1, 'apple': 1},
+         {'That': 1, 'is': 1, 'a': 1, 'pear': 1},
+         {'It': 1, 'is': 1, 'human': 1, 'being': 1},
+         {'Hello': 1, 'world': 1}]
 
         >>> corpus_idf_
         {'This': 0.6931471805599453,
@@ -462,21 +313,19 @@ def calculate_idf(raw_documents, rm_punc=False):
          'world': 0.6931471805599453}
     """
 
-    assert isinstance(raw_documents, pd.Series)
-
-    raw_docs = raw_documents.copy()
     if rm_punc:
-        raw_docs = raw_docs.map(remove_punctuation)
+        raw_docs = [remove_punctuation(x) for x in raw_documents]
+    else:
+        raw_docs = raw_documents
 
-    docs_tf = raw_docs.map(count_words)
-    tokens_in_docs = docs_tf.map(lambda x: list(x.keys()))
+    docs_tf = [count_words(x) for x in raw_docs]
+    tokens_in_docs = (x.keys() for x in docs_tf)
+    tokens = [k for keys in tokens_in_docs for k in keys]
 
-    n = len(raw_docs)
-    tokens = [w for tokens in tokens_in_docs for w in tokens]
-    tokens_counter = dict_to_dataframe(dict(collections.Counter(tokens)), 'token', 'count')
-    tokens_counter['idf'] = np.log(n / (1 + tokens_counter['count'].values))
+    tokens_counter_dict = dict(collections.Counter(tokens))
+    tokens_idf = np.log(len(raw_docs) / (1 + np.asarray(list(tokens_counter_dict.values()))))
 
-    corpus_idf = dict(zip(tokens_counter['token'], tokens_counter['idf']))
+    corpus_idf = dict(zip(tokens_counter_dict.keys(), tokens_idf))
 
     return docs_tf, corpus_idf
 
@@ -485,50 +334,73 @@ def calculate_tf_idf(raw_documents, rm_punc=False):
     """
     Count term frequency–inverse document frequency.
 
-    :param raw_documents: a series of documents
-    :type raw_documents: pandas.Series
-    :param rm_punc: whether to remove punctuation from ``raw_documents``, defaults to ``False``
+    :param raw_documents: a sequence of textual data
+    :type raw_documents: typing.Iterable or typing.Sequence
+    :param rm_punc: whether to remove punctuation from the input textual data, defaults to ``False``
     :type rm_punc: bool
-    :return: tf-idf of the ``raw_documents``
+    :return: tf-idf of the input textual data
     :rtype: dict
 
     **Examples**::
 
         >>> from pyhelpers.text import calculate_tf_idf
-        >>> import pandas
 
-        >>> raw_doc_ = [
+        >>> raw_doc = [
         ...     'This is an apple.',
         ...     'That is a pear.',
         ...     'It is human being.',
         ...     'Hello world!']
-        >>> raw_doc = pandas.Series(raw_doc_)
 
-        >>> docs_tf_idf_ = calculate_tf_idf(raw_doc, rm_punc=False)
+        >>> docs_tf_idf_ = calculate_tf_idf(raw_documents=raw_doc)
         >>> docs_tf_idf_
-        0    {'This': 0.6931471805599453, 'is': 0.0, 'an': ...
-        1    {'That': 0.6931471805599453, 'is': 0.0, 'a': 0...
-        2    {'It': 0.6931471805599453, 'is': 0.0, 'human':...
-        3    {'Hello': 0.6931471805599453, 'world': 0.69314...
-        dtype: object
+        {'This': 0.6931471805599453,
+         'is': 0.0,
+         'an': 0.6931471805599453,
+         'apple': 0.6931471805599453,
+         '.': 0.0,
+         'That': 0.6931471805599453,
+         'a': 0.6931471805599453,
+         'pear': 0.6931471805599453,
+         'It': 0.6931471805599453,
+         'human': 0.6931471805599453,
+         'being': 0.6931471805599453,
+         'Hello': 0.6931471805599453,
+         'world': 0.6931471805599453,
+         '!': 0.6931471805599453}
 
-        >>> docs_tf_idf_ = calculate_tf_idf(raw_doc, rm_punc=True)
+        >>> docs_tf_idf_ = calculate_tf_idf(raw_documents=raw_doc, rm_punc=True)
         >>> docs_tf_idf_
-        0    {'This': 0.6931471805599453, 'is': 0.0, 'an': ...
-        1    {'That': 0.6931471805599453, 'is': 0.0, 'a': 0...
-        2    {'It': 0.6931471805599453, 'is': 0.0, 'human':...
-        3    {'Hello': 0.6931471805599453, 'world': 0.69314...
-        dtype: object
+        {'This': 0.6931471805599453,
+         'is': 0.0,
+         'an': 0.6931471805599453,
+         'apple': 0.6931471805599453,
+         'That': 0.6931471805599453,
+         'a': 0.6931471805599453,
+         'pear': 0.6931471805599453,
+         'It': 0.6931471805599453,
+         'human': 0.6931471805599453,
+         'being': 0.6931471805599453,
+         'Hello': 0.6931471805599453,
+         'world': 0.6931471805599453}
     """
 
     docs_tf, corpus_idf = calculate_idf(raw_documents=raw_documents, rm_punc=rm_punc)
 
-    docs_tf_idf = docs_tf.apply(
-        lambda x: {k: v * corpus_idf[k] for k, v in x.items() if k in corpus_idf})
+    docs_tf_idf = {k: v * corpus_idf[k] for x in docs_tf for k, v in x.items() if k in corpus_idf}
 
     return docs_tf_idf
 
 
+def _vectorize_text(*txt):
+    txt_ = [
+        re.compile(r"\w+").findall(x.lower()) if isinstance(x, str) else [x_.lower() for x_ in x]
+        for x in txt]
+    doc_words = set().union(*txt_)
+
+    for x in txt_:
+        yield [x.count(word) for word in doc_words]
+
+
 def euclidean_distance_between_texts(txt1, txt2):
     """
     Compute Euclidean distance of two sentences.
@@ -537,31 +409,21 @@ def euclidean_distance_between_texts(txt1, txt2):
     :type txt1: str
     :param txt2: any text
     :type txt2: str
-    :return: Euclidean distance between ``txt1`` and ``txt2``
+    :return: Euclidean distance between the input textual data
     :rtype: float
 
-    **Example**::
+    **Examples**::
 
         >>> from pyhelpers.text import euclidean_distance_between_texts
 
         >>> txt_1, txt_2 = 'This is an apple.', 'That is a pear.'
 
-        >>> e_dist = euclidean_distance_between_texts(txt_1, txt_2)
-        >>> e_dist
-        2.6457513110645907
+        >>> euclidean_distance = euclidean_distance_between_texts(txt_1, txt_2)
+        >>> euclidean_distance
+        2.449489742783178
     """
 
-    if isinstance(txt1, str) and isinstance(txt2, str):
-        doc_words = set(txt1.split() + txt2.split())
-
-    else:
-        assert isinstance(txt1, list), isinstance(txt2, list)
-        doc_words = set(txt1 + txt2)
-
-    s1_count, s2_count = [], []
-    for word in doc_words:
-        s1_count.append(txt1.count(word))
-        s2_count.append(txt2.count(word))
+    s1_count, s2_count = list(_vectorize_text(txt1, txt2))
 
     # ed = np.sqrt(np.sum((np.array(s1_count) - np.array(s2_count)) ** 2))
     ed = np.linalg.norm(np.array(s1_count) - np.array(s2_count))
@@ -591,26 +453,14 @@ def cosine_similarity_between_texts(txt1, txt2, cosine_distance=False):
 
         >>> cos_sim = cosine_similarity_between_texts(txt_1, txt_2)
         >>> cos_sim
-        0.6963106238227914
+        0.25
 
         >>> cos_dist = cosine_similarity_between_texts(txt_1, txt_2, cosine_distance=True)
         >>> cos_dist  # 1 - cos_sim
-        0.3036893761772086
+        0.75
     """
 
-    if isinstance(txt1, str) and isinstance(txt2, str):
-        doc_words = set(txt1.split() + txt2.split())
-
-    else:
-        assert isinstance(txt1, list), isinstance(txt2, list)
-        doc_words = set(txt1 + txt2)
-
-    s1_count, s2_count = [], []
-    for word in doc_words:
-        s1_count.append(txt1.count(word))
-        s2_count.append(txt2.count(word))
-
-    s1_count, s2_count = np.array(s1_count), np.array(s2_count)
+    s1_count, s2_count = map(np.array, _vectorize_text(txt1, txt2))
 
     similarity = np.dot(s1_count, s2_count)
     cos_similarity = np.divide(similarity, np.linalg.norm(s1_count) * np.linalg.norm(s2_count))
@@ -621,76 +471,189 @@ def cosine_similarity_between_texts(txt1, txt2, cosine_distance=False):
     return cos_similarity
 
 
-""" == Conversion of text files ============================================================== """
+# ==================================================================================================
+# Textual data comparison
+# ==================================================================================================
 
 
-def convert_md_to_rst(path_to_md, path_to_rst, verbose=False, pandoc_exe=None, **kwargs):
+def find_matched_str(x, lookup_list):
     """
-    Convert a `Markdown <https://daringfireball.net/projects/markdown/>`_ file (.md)
-    to a `reStructuredText <https://docutils.readthedocs.io/en/sphinx-docs/user/rst/quickstart.html>`_
-    (.rst) file.
+    Find all that are matched with a string from among a sequence of strings.
 
-    This function relies on
-    `Pandoc <https://pandoc.org/>`_ or `pypandoc <https://github.com/bebraw/pypandoc>`_.
+    :param x: a string-type variable
+    :type x: str
+    :param lookup_list: a sequence of strings for lookup
+    :type lookup_list: typing.Iterable
+    :return: a generator containing all that are matched with ``x``
+    :rtype: typing.Generator or None
 
-    :param path_to_md: path where a markdown file is saved
-    :type path_to_md: str
-    :param path_to_rst: path where a reStructuredText file is saved
-    :type path_to_rst: str
-    :param verbose: whether to print relevant information in console as the function runs,
-        defaults to ``False``
-    :type verbose: bool
-    :param pandoc_exe: absolute path to 'pandoc.exe', defaults to ``None``
-        (on Windows, use the default installation path - ``"C:\\Program Files\\Pandoc\\pandoc.exe"``)
-    :type pandoc_exe: str or None
-    :param kwargs: [optional] parameters of `pypandoc.convert_file <https://github.com/bebraw/pypandoc>`_
+    **Examples**::
 
-    **Example**::
+        >>> from pyhelpers.text import find_matched_str
 
-        >>> from pyhelpers.text import convert_md_to_rst
-        >>> from pyhelpers.dir import cd
+        >>> lookup_lst = ['abc', 'aapl', 'app', 'ap', 'ape', 'apex', 'apel']
+        >>> res = find_matched_str('apple', lookup_lst)
+        >>> list(res)
+        []
 
-        >>> dat_dir = cd("tests\\documents")
+        >>> lookup_lst += ['apple']
+        >>> lookup_lst
+        ['abc', 'aapl', 'app', 'ap', 'ape', 'apex', 'apel', 'apple']
 
-        >>> path_to_md_file = cd(dat_dir, "readme.md")
-        >>> path_to_rst_file = cd(dat_dir, "readme.rst")
+        >>> res = find_matched_str('apple', lookup_lst)
+        >>> list(res)
+        ['apple']
 
-        >>> convert_md_to_rst(path_to_md_file, path_to_rst_file, verbose=True)
-        Converting "tests\\data\\markdown.md" to "tests\\data\\markdown.rst" ... Done.
+        >>> res = find_matched_str(r'app(le)?', lookup_lst)
+        >>> list(res)
+        ['app', 'apple']
     """
 
-    abs_md_path, abs_rst_path = pathlib.Path(path_to_md), pathlib.Path(path_to_rst)
-    # assert abs_md_path.suffix == ".md" and abs_rst_path.suffix == ".rst"
+    if x is not None:
+        for y in lookup_list:
+            if re.match(x, y, re.IGNORECASE):
+                yield y
 
-    if verbose:
-        rel_md_path, rel_rst_path = map(
-            lambda x: pathlib.Path(os.path.relpath(x)), (abs_md_path, abs_rst_path))
 
-        if not os.path.exists(abs_rst_path):
-            msg = "Converting \"{}\" to \"{}\"".format(rel_md_path, rel_rst_path)
+def _find_str_by_difflib(x, lookup_list, n, ignore_punctuation, **kwargs):
+    difflib_ = _check_dependency(name='difflib')
+
+    x_, lookup_dict = x.lower(), {y.lower(): y for y in lookup_list}
+
+    if ignore_punctuation:
+        x_ = remove_punctuation(x_)
+        lookup_dict = {remove_punctuation(k): v for k, v in lookup_dict.items()}
+
+    sim_str_ = difflib_.get_close_matches(word=x_, possibilities=lookup_dict.keys(), n=n, **kwargs)
+
+    if not sim_str_:
+        sim_str = None
+    elif len(sim_str_) == 1:
+        sim_str = lookup_dict[sim_str_[0]]
+    else:
+        sim_str = [lookup_dict[k] for k in sim_str_]
+
+    return sim_str
+
+
+def _find_str_by_fuzzywuzzy(x, lookup_list, n, **kwargs):
+    fuzzywuzzy_fuzz = _check_dependency(name='fuzzywuzzy.fuzz')
+
+    lookup_list_ = list(lookup_list)
+
+    l_distances = [fuzzywuzzy_fuzz.token_set_ratio(s1=x, s2=a, **kwargs) for a in lookup_list_]
+
+    if sum(l_distances) == 0:
+        sim_str = None
+    else:
+        if n == 1:
+            sim_str = lookup_list_[l_distances.index(max(l_distances))]
         else:
-            msg = "Updating \"{}\" at \"{}\\\"".format(rel_rst_path.name, rel_rst_path.parent)
-        print(msg, end=" ... ")
+            sim_str = [lookup_list_[i] for i in np.argsort(l_distances)[::-1]][:n]
 
-    pandoc_exe_ = copy.copy(pandoc_exe)
-    if pandoc_exe_ is None:
-        pandoc_exe_ = find_executable(
-            app_name="pandoc.exe", possibilities=["C:\\Program Files\\Pandoc\\pandoc.exe"])
+    return sim_str
 
-    try:
-        subprocess.call(
-            '"{}" "{}" -f markdown -t rst -s -o "{}"'.format(pandoc_exe_, abs_md_path, abs_rst_path))
 
-        if verbose:
-            print("Done.")
+def find_similar_str(x, lookup_list, n=1, ignore_punctuation=True, method='difflib', **kwargs):
+    """
+    From among a sequence of strings, find ``n`` ones that are similar to ``x``.
 
-    except FileNotFoundError:
-        import pypandoc
+    :param x: a string-type variable
+    :type x: str
+    :param lookup_list: a sequence of strings for lookup
+    :type lookup_list: typing.Iterable
+    :param n: number of similar strings to return, defaults to ``1``;
+        if ``n=None``, the function returns a sorted ``lookup_list`` (in descending order of similarity)
+    :type n: int or None
+    :param method: options include ``'difflib'`` (default) and ``'fuzzywuzzy'``
 
-        pypandoc.convert_file(str(abs_md_path), 'rst', outputfile=str(abs_rst_path), **kwargs)
+        - if ``method='difflib'``, the function relies on `difflib.get_close_matches`_
+        - if ``method='fuzzywuzzy'``, the function relies on `fuzzywuzzy.fuzz.token_set_ratio`_
 
-        if verbose:
-            print("Done.")
+    :type method: str or types.FunctionType
 
-    except Exception as e:
-        print("Failed. {}".format(e))
+    :param ignore_punctuation: whether to ignore puctuations in the search for similar texts
+    :type ignore_punctuation: bool
+    :param kwargs: [optional] parameters (e.g. ``cutoff=0.6``) of `difflib.get_close_matches`_ or
+        `fuzzywuzzy.fuzz.token_set_ratio`_, depending on ``method``
+    :return: a string-type variable that should be similar to (or the same as) ``x``
+    :rtype: str or list or None
+
+    .. _`difflib.get_close_matches`:
+        https://docs.python.org/3/library/difflib.html#difflib.get_close_matches
+    .. _`fuzzywuzzy.fuzz.token_set_ratio`:
+        https://github.com/seatgeek/fuzzywuzzy
+
+    .. note::
+
+        - By default, the function uses the built-in module
+          `difflib <https://docs.python.org/3/library/difflib.html>`_; when we set the parameter
+          ``method='fuzzywuzzy'``, the function then relies on
+          `FuzzyWuzzy <https://pypi.org/project/fuzzywuzzy/>`_, which is not an essential dependency
+          for installing pyhelpers. We could however use ``pip`` (or ``conda``) to install it first
+          separately.
+
+    **Examples**::
+
+        >>> from pyhelpers.text import find_similar_str
+
+        >>> lookup_lst = ['Anglia',
+        ...               'East Coast',
+        ...               'East Midlands',
+        ...               'North and East',
+        ...               'London North Western',
+        ...               'Scotland',
+        ...               'South East',
+        ...               'Wales',
+        ...               'Wessex',
+        ...               'Western']
+
+        >>> y = find_similar_str(x='angle', lookup_list=lookup_lst)
+        >>> y
+        'Anglia'
+        >>> y = find_similar_str(x='angle', lookup_list=lookup_lst, n=2)
+        >>> y
+        ['Anglia', 'Wales']
+
+        >>> y = find_similar_str(x='angle', lookup_list=lookup_lst, method='fuzzywuzzy')
+        >>> y
+        'Anglia'
+        >>> y = find_similar_str('angle', lookup_lst, n=2, method='fuzzywuzzy')
+        >>> y
+        ['Anglia', 'Wales']
+
+        >>> y = find_similar_str(x='x', lookup_list=lookup_lst)
+        >>> y is None
+        True
+        >>> y = find_similar_str(x='x', lookup_list=lookup_lst, cutoff=0.25)
+        >>> y
+        'Wessex'
+        >>> y = find_similar_str(x='x', lookup_list=lookup_lst, n=2, cutoff=0.25)
+        >>> y
+        'Wessex'
+
+        >>> y = find_similar_str(x='x', lookup_list=lookup_lst, method='fuzzywuzzy')
+        >>> y
+        'Wessex'
+        >>> y = find_similar_str(x='x', lookup_list=lookup_lst, n=2, method='fuzzywuzzy')
+        >>> y
+        ['Wessex', 'Western']
+    """
+
+    methods = {'difflib', 'fuzzywuzzy', None}
+    assert method in methods or callable(method), \
+        "Invalid input: `method`. Valid options can include {}.".format(methods)
+
+    if method == 'difflib' or method is None:
+        sim_str = _find_str_by_difflib(x, lookup_list, n, ignore_punctuation, **kwargs)
+
+    elif method == 'fuzzywuzzy':
+        sim_str = _find_str_by_fuzzywuzzy(x, lookup_list, n, **kwargs)
+
+    elif callable(method):
+        sim_str = method(x, lookup_list, **kwargs)
+
+    else:
+        sim_str = None
+
+    return sim_str
